# python-stdlib
[![CircleCI](https://circleci.com/gh/dalloriam/python-stdlib.svg?style=svg)](https://circleci.com/gh/dalloriam/python-stdlib)

Personal standard library. Modules here are more quick utilities that I use to accelerate the development of tools I
make for myself. When modules grow big or become useful for others, I'll extract them into separate libraries.
